@@ -1171,63 +1171,69 @@ class WordToken(models.Model):
     def get_details(self):
         if self.WordType.isWord():
             sp,bp = self.WordType.getPhonoProb()
+            cont = OrderedDict(('Previous conditional probability', self.getPreviousCondProb()),
+                        ('Following conditional probability', self.getFollowingCondProb()),
+                        ('Previous speaking rate', self.getPreviousSpeakingRate()),
+                        ('Following speaking rate', self.getFollowingSpeakingRate()),
+                        ('Previous distance to pause', self.getPrevDistToPause()),
+                        ('Following distance to pause', self.getFollDistToPause()),
+                        ('Previous semantic predictability', self.getPrevSemPred()),
+                        ('Following semantic predictability',self.getFollSemPred()))
+            lex = OrderedDict(('Word': str(self.WordType)),
+                            ('Underlying representation', self.WordType.getUR()),
+                            ('Buckeye frequency', self.WordType.getFreq()),
+                            ('Buckeye single-phone probability', sp),
+                            ('Buckeye bi-phone probability', bp),
+                            ('Buckeye neighbourhood density', self.WordType.getND()),
+                            ('Buckeye frequency-weighted neighbourhood density', self.WordType.getFWND()),
+                            ('Stress vowel', self.WordType.getStressVowel()))
+            tok = OrderedDict(('Dialog', str(self.Dialog)),
+                            ('Surface representation', self.getSR()),
+                            ('Buckeye category', str(self.Category)),
+                            ('Stress vowel F1', self.getStrF1()),
+                            ('Stress vowel F2', self.getStrF2()),
+                            ('Repetitions', self.getRepetitions()),
+                            ('Given', self.getRecentRepetition()))
+            speak = OrderedDict(('Speaker', str(self.Dialog.Speaker)),
+                            ('Gender', self.Dialog.Speaker.Gender),
+                            ('Age', self.Dialog.Speaker.Age),
+                            ('Number of formants', self.Dialog.Speaker.NumFormants),
+                            ('Formant ceiling', self.Dialog.Speaker.Ceiling),
+                            ('Vowel center', self.Dialog.Speaker.getCenter()),
+                            ('Average speaking rate', self.Dialog.Speaker.getAvgSpeakingRate()))
             out = {'Preceding': self.getPreviousContext(),
                     'Following': self.getFollowingContext(),
                     'Word': str(self.WordType),
                     'NFormants': self.Dialog.Speaker.NumFormants,
                     'Ceiling': self.Dialog.Speaker.Ceiling,
                     'Token': self.pk,
-                    'Contextual':{
-                                'Previous conditional probability': self.getPreviousCondProb(),
-                                'Following conditional probability': self.getFollowingCondProb(),
-                                'Previous speaking rate': self.getPreviousSpeakingRate(),
-                                'Following speaking rate': self.getFollowingSpeakingRate(),
-                                'Previous distance to pause': self.getPrevDistToPause(),
-                                'Following distance to pause': self.getFollDistToPause(),
-                                'Previous semantic predictability': self.getPrevSemPred(),
-                                'Following semantic predictability':self.getFollSemPred()},
-                    'Lexical':{'Word': str(self.WordType),
-                            'Underlying representation': self.WordType.getUR(),
-                            'Buckeye frequency': self.WordType.getFreq(),
-                            'Buckeye single-phone probability': sp,
-                            'Buckeye bi-phone probability': bp,
-                            'Buckeye neighbourhood density': self.WordType.getND(),
-                            'Buckeye frequency-weighted neighbourhood density': self.WordType.getFWND(),
-                            'Stress vowel': self.WordType.getStressVowel()},
-                    'Token':{'Dialog': str(self.Dialog),
-                            'Surface representation': self.getSR(),
-                            'Buckeye category': str(self.Category),
-                            'Stress vowel F1': self.getStrF1(),
-                            'Stress vowel F2': self.getStrF2(),
-                            'Repetitions': self.getRepetitions(),
-                            'Given': self.getRecentRepetition()},
-                    'Speaker':{'Speaker': str(self.Dialog.Speaker),
-                            'Gender': self.Dialog.Speaker.Gender,
-                            'Age': self.Dialog.Speaker.Age,
-                            'Number of formants': self.Dialog.Speaker.NumFormants,
-                            'Formant ceiling': self.Dialog.Speaker.Ceiling,
-                            'Vowel center': self.Dialog.Speaker.getCenter(),
-                            'Average speaking rate': self.Dialog.Speaker.getAvgSpeakingRate()}}
+                    'Contextual': cont,
+                    'Lexical':lex,
+                    'Token':tok,
+                    'Speaker':speak}
         else:
+            cont = OrderedDict(('Previous speaking rate', self.getPreviousSpeakingRate()),
+                        ('Following speaking rate', self.getFollowingSpeakingRate()),
+                        ('Previous distance to pause', self.getPrevDistToPause()),
+                        ('Following distance to pause', self.getFollDistToPause()))
+            tok = OrderedDict(('Dialog', str(self.Dialog)),
+                            ('Buckeye category', str(self.Category)))
+            speak = OrderedDict(('Speaker', str(self.Dialog.Speaker)),
+                            ('Gender', self.Dialog.Speaker.Gender),
+                            ('Age', self.Dialog.Speaker.Age),
+                            ('Number of formants', self.Dialog.Speaker.NumFormants),
+                            ('Formant ceiling', self.Dialog.Speaker.Ceiling),
+                            ('Vowel center', self.Dialog.Speaker.getCenter()),
+                            ('Average speaking rate', self.Dialog.Speaker.getAvgSpeakingRate()))
             out = {'Preceding': self.getPreviousContext(),
                     'Following': self.getFollowingContext(),
                     'Word': str(self.WordType),
                     'NFormants': self.Dialog.Speaker.NumFormants,
                     'Ceiling': self.Dialog.Speaker.Ceiling,
                     'Token': self.pk,
-                    'Contextual':{'Previous speaking rate': self.getPreviousSpeakingRate(),
-                                'Following speaking rate': self.getFollowingSpeakingRate(),
-                                'Previous distance to pause': self.getPrevDistToPause(),
-                                'Following distance to pause': self.getFollDistToPause(),},
-                'Token':{'Dialog': str(self.Dialog),
-                            'Buckeye category': str(self.Category)},
-                'Speaker':{'Speaker': str(self.Dialog.Speaker),
-                            'Gender': self.Dialog.Speaker.Gender,
-                            'Age': self.Dialog.Speaker.Age,
-                            'Number of formants': self.Dialog.Speaker.NumFormants,
-                            'Formant ceiling': self.Dialog.Speaker.Ceiling,
-                            'Vowel center': self.Dialog.Speaker.getCenter(),
-                            'Average speaking rate': self.Dialog.Speaker.getAvgSpeakingRate()}}
+                    'Contextual':cont,
+                'Token':tok,
+                'Speaker':speak}
 
         return out
 
